## Summary

The table shows the search sources available in the dblp package. The main source is dblp.org, which provides curated metadata for computer science and information technology. The size of the database is over 5,750,000 entries.

## search

### API search

ℹ️ Restriction: API searches do not support complex queries (yet)

Run a search on dblp.org and paste the url in the following command:

```
colrev search --add colrev.dblp -p "https://dblp.org/search?q=microsourcing"
```

### TOC search

TODO

## prep

linking metadata

## Links

- License: [Open Data Commons ODC-BY 1.0 license](https://dblp.org/db/about/copyright.html)
- [DBLP](https://dblp.org/)
